@@ -6,28 +6,34 @@ from loguru import logger
 from .etl import DATA_DIR, collections
 
 
-@click.command()
-@click.version_option()
-@click.argument(
-    "kind", type=click.Choice(["city-tax", "city-nontax", "city-other-govts", "wage"])
-)
-@click.option("--month", type=int)
-@click.option("--year", type=int)
-@click.option("--dry-run", is_flag=True)
-def monthly_collections_etl(kind, month=None, year=None, dry_run=False) -> None:
-    """Run the ETL pipeline for monthly collections"""
+def _fiscal_year_etl(cls, fiscal_year, dry_run):
+    """Internal function to run ETL on fiscal year data."""
 
-    # Get the ETL class
-    ETL = {
-        "wage": collections.WageCollectionsByIndustry,
-        "city-tax": collections.CityTaxCollections,
-        "city-nontax": collections.CityNonTaxCollections,
-        "city-other-govts": collections.CityOtherGovtsCollections,
-    }
-    cls = ETL[kind]
+    # Get the directory of raw files
+    dirname = cls.get_data_directory("raw")
 
-    # Log
-    logger.info(f"Processing ETL for '{cls.__name__}'")
+    # Glob the PDF files
+    if fiscal_year is not None:
+        fy_tag = str(fiscal_year)[-2:]
+        files = dirname.glob(f"FY{fy_tag}.pdf")
+    else:
+        files = dirname.glob("*.pdf")
+
+    # Do all the files
+    for f in sorted(files):
+
+        # Get fiscal_year
+        fiscal_year = int(f"20{f.stem[2:]}")
+        logger.info(f"Processing fiscal_year='{fiscal_year}'")
+
+        # ETL
+        if not dry_run:
+            report = cls(fiscal_year=fiscal_year)
+            report.extract_transform_load()
+
+
+def _monthly_etl(cls, month, year, dry_run):
+    """Internal function to run ETL on monthly data."""
 
     # If month is provided, we need the year too
     if month is not None:
@@ -58,65 +64,92 @@ def monthly_collections_etl(kind, month=None, year=None, dry_run=False) -> None:
         # Do all the files
         for f in sorted(files):
 
-            # Get month and year
-            year, month = map(int, f.stem.split("_"))
-            logger.info(f"Processing year='{year}' and month='{month}'")
+            # Get month, year
+            if "Q" in f.stem:
+                year, quarter = f.stem.split("_")
+                quarter = int(quarter[1:])
+                months = {1: [1, 2, 3], 2: [4, 5, 6], 3: [7, 8, 9], 4: [10, 11, 12]}
+                months = months[quarter]
+            else:
+                year, month = map(int, f.stem.split("_"))
+                months = [month]
 
-            # ETL
-            if not dry_run:
-                report = cls(year=year, month=month)
-                report.extract_transform_load()
+            # Run each month
+            for month in months:
+                logger.info(f"Processing year='{year}' and month='{month}'")
+
+                # ETL
+                if not dry_run:
+                    report = cls(year=int(year), month=int(month))
+                    report.extract_transform_load()
 
 
 @click.command()
 @click.version_option()
-@click.option("--fiscal-year", type=int)
+@click.argument(
+    "kind",
+    type=click.Choice(["city-tax", "city-nontax", "city-other-govts", "school-tax"]),
+)
+@click.option("--month", type=int)
+@click.option("--year", type=int)
 @click.option("--dry-run", is_flag=True)
-def sales_collections_etl(fiscal_year=None, dry_run=False) -> None:
-    """Run the ETL pipeline for monthly sales collections"""
+def etl_monthly_collections(kind, month=None, year=None, dry_run=False) -> None:
+    """Run the ETL pipeline for monthly collections"""
 
     # Get the ETL class
-    cls = collections.SalesCollectionsByIndustry
+    ETL = {
+        "city-tax": collections.CityTaxCollections,
+        "city-nontax": collections.CityNonTaxCollections,
+        "city-other-govts": collections.CityOtherGovtsCollections,
+        "school-tax": collections.SchoolTaxCollections,
+    }
+    cls = ETL[kind]
 
     # Log
     logger.info(f"Processing ETL for '{cls.__name__}'")
 
-    # Get the directory of raw files
-    dirname = cls.get_data_directory("raw")
+    # Run the ETL
+    _monthly_etl(cls, month, year, dry_run)
 
-    # Glob the PDF files
-    if fiscal_year is not None:
-        fy_tag = str(fiscal_year)[-2:]
-        files = dirname.glob(f"FY{fy_tag}.pdf")
-    else:
-        files = dirname.glob("*.pdf")
 
-    # Do all the files
-    for f in sorted(files):
+@click.command()
+@click.version_option()
+@click.argument(
+    "kind",
+    type=click.Choice(["wage", "rtt", "sales", "birt"]),
+)
+@click.option("--month", type=int)
+@click.option("--year", type=int)
+@click.option("--dry-run", is_flag=True)
+def etl_sector_collections(
+    kind, month=None, year=None, fiscal_year=None, dry_run=False
+) -> None:
+    """Run the ETL pipeline for sector collections"""
 
-        # Get fiscal_year
-        fiscal_year = int(f"20{f.stem[2:]}")
-        logger.info(f"Processing fiscal_year='{fiscal_year}'")
+    # Get the ETL class
+    ETL = {
+        "wage": collections.WageCollectionsBySector,
+        "sales": collections.SalesCollectionsBySector,
+        "rtt": collections.RTTCollectionsBySector,
+        "birt": collections.BIRTCollectionsBySector,
+    }
+    cls = ETL[kind]
 
+    # Log
+    logger.info(f"Processing ETL for '{cls.__name__}'")
+
+    # BIRT
+    if kind == "birt":
         # ETL
         if not dry_run:
-            report = cls(fiscal_year=fiscal_year)
+            report = cls()
             report.extract_transform_load()
-
-
-@click.command()
-@click.version_option()
-@click.option("--dry-run", is_flag=True)
-def birt_collections_etl(fiscal_year=None, dry_run=False) -> None:
-    """Run the ETL pipeline for monthly BIRT collections"""
-
-    # Get the ETL class
-    cls = collections.BIRTCollectionsByIndustry
-
-    # Log
-    logger.info(f"Processing ETL for '{cls.__name__}'")
-
-    # ETL
-    if not dry_run:
-        report = cls()
-        report.extract_transform_load()
+    # Wage
+    elif kind == "wage":
+        _monthly_etl(cls, month, year, dry_run)
+    # Sales
+    elif kind == "sales":
+        _fiscal_year_etl(cls, fiscal_year, dry_run)
+    # RTT
+    elif kind == "rtt":
+        _monthly_etl(cls, month, year, dry_run)
